==> wine_0.9.25.orig.tar.gz: wine-0.9.25.orig/dlls/mshtml/resource.h <==
/*
 * Copyright 2005 Jacek Caban
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
 */

#define IDS_HTMLDISABLED    7500
#define IDS_HTMLDOCUMENT    7501
#define IDS_DOWNLOADING     7502
#define IDS_INSTALLING      7503

#define ID_DWL_DIALOG       7600
#define ID_DWL_PROGRESS     7601
#define ID_DWL_INSTALL      7602
#define ID_DWL_STATUS       7603

#define IDR_BROWSE_CONTEXT_MENU  24641

#define IDM_TRACETAGS           6004
#define IDM_RESOURCEFAILURES    6005
#define IDM_DUMPTRACKINGINFO    6006
#define IDM_DEBUGBREAK          6007
#define IDM_DEBUGVIEW           6008
#define IDM_DUMPTREE            6009
#define IDM_DUMPLINES           6010

#define IDM_SAVEHTML            6012
#define IDM_MEMORYMONITOR       6013
#define IDM_PERFORMANCEMETERS   6014
#define IDM_DUMPDISPLAYTREE     6015
#define IDM_DUMPFORMATCACHES    6016
#define IDM_DUMPLAYOUTRECTS     6017

#define _IDM_REFRESH            6042

==> wine_1.1.24.orig.tar.gz: wine-1.1.24/dlls/mshtml/resource.h <==
/*
 * Copyright 2005 Jacek Caban
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
 */

#define IDS_HTMLDISABLED    7500
#define IDS_HTMLDOCUMENT    7501
#define IDS_DOWNLOADING     7502
#define IDS_INSTALLING      7503

#define ID_DWL_DIALOG       7600
#define ID_DWL_PROGRESS     7601
#define ID_DWL_INSTALL      7602
#define ID_DWL_STATUS       7603

#define ID_PROMPT_DIALOG    7700
#define ID_PROMPT_PROMPT    7701
#define ID_PROMPT_EDIT      7702

#define IDS_MESSAGE_BOX_TITLE  2213

#define IDS_PRINT_HEADER_TEMPLATE  8403
#define IDS_PRINT_FOOTER_TEMPLATE  8404

#define IDR_BROWSE_CONTEXT_MENU  24641

#define IDM_TRACETAGS           6004
#define IDM_RESOURCEFAILURES    6005
#define IDM_DUMPTRACKINGINFO    6006
#define IDM_DEBUGBREAK          6007
#define IDM_DEBUGVIEW           6008
#define IDM_DUMPTREE            6009
#define IDM_DUMPLINES           6010

#define IDM_SAVEHTML            6012
#define IDM_MEMORYMONITOR       6013
#define IDM_PERFORMANCEMETERS   6014
#define IDM_DUMPDISPLAYTREE     6015
#define IDM_DUMPFORMATCACHES    6016
#define IDM_DUMPLAYOUTRECTS     6017

#define _IDM_REFRESH            6042

#define IDD_HYPERLINK           8000

#define IDC_URL                 9001
#define IDC_TYPE                9002
